@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -33,13 +33,14 @@
 #include "exports.h"
 
 class Account;
-class Contact;
 
 class KADUAPI ContactManager : public QObject, public Manager<Contact>
 {
 	Q_OBJECT
 	Q_DISABLE_COPY(ContactManager)
 
+	friend class Core;
+
 	static ContactManager * Instance;
 
 	QList<Contact> DirtyContacts;
@@ -95,7 +96,4 @@ signals:
 
 };
 
-// for MOC
-#include "contacts/contact.h"
-
 #endif // CONTACT_MANAGER_H
