@@ -2,7 +2,7 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2008, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2008, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ public:
 	explicit ChangeStatusAction(QObject *parent);
 	virtual ~ChangeStatusAction();
 
-	virtual QToolButton::ToolButtonPopupMode buttonPopupMode()
+	virtual QToolButton::ToolButtonPopupMode buttonPopupMode() const
 	{
 		return QToolButton::InstantPopup;
 	}
