@@ -1,6 +1,9 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -28,6 +31,9 @@ class AddRoomChatAction : public ActionDescription
 {
 	Q_OBJECT
 
+private slots:
+	void updateAddChatMenuItem();
+
 protected:
 	virtual void triggered(QWidget *widget, ActionContext *context, bool toggled);
 
