@@ -2,9 +2,9 @@
  * %kadu copyright begin%
  * Copyright 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
- * Copyright 2010, 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2014 Piotr Dąbrowski (ultr@ultr.pl)
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QtGui/QApplication>
 #include <QtGui/QCheckBox>
 #include <QtGui/QDialogButtonBox>
 #include <QtGui/QFileDialog>
@@ -34,9 +35,9 @@
 
 #include "buddies/group.h"
 #include "configuration/configuration-file.h"
-
 #include "icons/kadu-icon.h"
 #include "misc/change-notifier.h"
+#include "misc/change-notifier-lock.h"
 #include "misc/misc.h"
 
 #include "group-properties-window.h"
@@ -51,15 +52,15 @@ GroupPropertiesWindow::GroupPropertiesWindow(Group editedGroup, QWidget *parent)
 
 	QVBoxLayout *main_layout = new QVBoxLayout(this);
 
-	QGroupBox *behaviourGroupBox = new QGroupBox;
-	QVBoxLayout *behaviour_layout = new QVBoxLayout(behaviourGroupBox);
-	behaviour_layout->setSpacing(5);
-	behaviourGroupBox->setTitle(tr("Behaviour"));
+	QGroupBox *behaviorGroupBox = new QGroupBox;
+	QVBoxLayout *behavior_layout = new QVBoxLayout(behaviorGroupBox);
+	behavior_layout->setSpacing(5);
+	behaviorGroupBox->setTitle(tr("Behavior"));
 
-	notifyCheckBox = new QCheckBox(tr("Notify about status changes"), behaviourGroupBox);
+	notifyCheckBox = new QCheckBox(tr("Notify about status changes"), behaviorGroupBox);
 	notifyCheckBox->setChecked(group.notifyAboutStatusChanges());
 
-	offlineCheckBox = new QCheckBox(tr("Offline for this group"), behaviourGroupBox);
+	offlineCheckBox = new QCheckBox(tr("Offline for this group"), behaviorGroupBox);
 	offlineCheckBox->setChecked(group.offlineToGroup());
 	offlineCheckBox->setToolTip(tr("Supported for Gadu-Gadu network"));
 
@@ -70,13 +71,13 @@ GroupPropertiesWindow::GroupPropertiesWindow(Group editedGroup, QWidget *parent)
 	info->setVisible(offlineCheckBox->isChecked());
 	connect(offlineCheckBox, SIGNAL(toggled(bool)), info, SLOT(setVisible(bool)));
 
-	allGroupCheckBox = new QCheckBox(tr("Show in group \"All\""), behaviourGroupBox);
+	allGroupCheckBox = new QCheckBox(tr("Show in group \"All\""), behaviorGroupBox);
 	allGroupCheckBox->setChecked(group.showInAllGroup());
 
-	behaviour_layout->addWidget(notifyCheckBox);
-	behaviour_layout->addWidget(offlineCheckBox);
-	behaviour_layout->addWidget(info);
-	behaviour_layout->addWidget(allGroupCheckBox);
+	behavior_layout->addWidget(notifyCheckBox);
+	behavior_layout->addWidget(offlineCheckBox);
+	behavior_layout->addWidget(info);
+	behavior_layout->addWidget(allGroupCheckBox);
 
 	QGroupBox *lookGroupBox = new QGroupBox;
 	QVBoxLayout *look_layout = new QVBoxLayout(lookGroupBox);
@@ -128,7 +129,7 @@ GroupPropertiesWindow::GroupPropertiesWindow(Group editedGroup, QWidget *parent)
 	connect(applyButton, SIGNAL(clicked()), this, SLOT(applyClicked()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(close()));
 
-	main_layout->addWidget(behaviourGroupBox);
+	main_layout->addWidget(behaviorGroupBox);
 	main_layout->addWidget(lookGroupBox);
 	main_layout->addSpacing(10);//TODO
 	main_layout->addWidget(buttons_layout);
@@ -151,8 +152,7 @@ void GroupPropertiesWindow::selectIcon()
 
 void GroupPropertiesWindow::applyClicked()
 {
-	if (group)
-		group.changeNotifier()->block();
+	ChangeNotifierLock lock(group.changeNotifier());
 
 	group.setShowName(nameCheckBox->isChecked());
 	group.setShowIcon(iconCheckBox->isChecked());
@@ -160,9 +160,6 @@ void GroupPropertiesWindow::applyClicked()
 	group.setNotifyAboutStatusChanges(notifyCheckBox->isChecked());
 	group.setOfflineToGroup(offlineCheckBox->isChecked());
 	group.setShowInAllGroup(allGroupCheckBox->isChecked());
-
-	if (group)
-		group.changeNotifier()->unblock();
 }
 
 void GroupPropertiesWindow::okClicked()
@@ -181,3 +178,5 @@ void GroupPropertiesWindow::keyPressEvent(QKeyEvent *e)
 	else
 		QWidget::keyPressEvent(e);
 }
+
+#include "moc_group-properties-window.cpp"
