@@ -1,6 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -18,9 +19,10 @@
  */
 
 #include "buddies/buddy.h"
+#include "buddies/group.h"
 #include "chat/chat.h"
-#include "contacts/contact.h"
 #include "contacts/contact-set.h"
+#include "contacts/contact.h"
 
 #include "name-talkable-filter.h"
 
@@ -130,3 +132,5 @@ void NameTalkableFilter::setName(const QString &name)
 	Name = name;
 	emit filterChanged();
 }
+
+#include "moc_name-talkable-filter.cpp"
