@@ -1,11 +1,12 @@
 /*
  * %kadu copyright begin%
  * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
+ * Copyright 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2004 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2002, 2003, 2004, 2005 Adrian Smarzewski (adrian@kadu.net)
  * Copyright 2002, 2003, 2004 Tomasz Chiliński (chilek@chilan.com)
- * Copyright 2007, 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2007 Dawid Stawiarski (neeo@kadu.net)
  * Copyright 2005 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
@@ -33,15 +34,11 @@
 
 QString IconThemeManager::defaultTheme()
 {
-#ifdef Q_WS_MAEMO_5
-	return QLatin1String("glass");
-#else
 	return QLatin1String("default");
-#endif
 }
 
 IconThemeManager::IconThemeManager(QObject *parent) :
-		ThemeManager(false, parent)
+		ThemeManager(parent)
 {
 }
 
@@ -70,3 +67,5 @@ bool IconThemeManager::isValidThemePath(const QString &themePath) const
 
 	return kaduIconFile.exists();
 }
+
+#include "moc_icon-theme-manager.cpp"
