@@ -1,22 +1,6 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
 <context>
     <name>@default</name>
-    <message>
-        <source>Kadu</source>
-        <translation>Kadu</translation>
-    </message>
-    <message>
-        <source>Advanced</source>
-        <translation>Avancé</translation>
-    </message>
-    <message>
-        <source>Kadu&apos;s Main Window Autohide</source>
-        <translation>Fenêtre principale d&apos;Autohide Kadu</translation>
-    </message>
-    <message>
-        <source>Use autohide</source>
-        <translation>Utiliser autohide</translation>
-    </message>
     <message>
         <source>Autohide idle time</source>
         <translation>Temps d&apos;inactivité avant de déclenchement d&apos;Autohide </translation>
@@ -25,6 +9,22 @@
         <source>%n second(s)</source>
         <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
     </message>
+    <message>
+        <source>Buddies list</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>General</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Buddies window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Hide buddy list window when unused</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AutoHide</name>
