@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="de">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -48,7 +46,7 @@
     </message>
     <message>
         <source>Cenzor</source>
-        <translation type="unfinished">Zensor</translation>
+        <translation>Zensor</translation>
     </message>
 </context>
 <context>
@@ -66,4 +64,4 @@
         <translation>Löschen</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
