@@ -1,10 +1,6 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
 <context>
     <name>@default</name>
-    <message>
-        <source>Kadu</source>
-        <translation>Kadu</translation>
-    </message>
     <message>
         <source>Tray</source>
         <translation>Panel</translation>
@@ -41,6 +37,10 @@
         <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
         <translation>Povolit přesun ikony po ploše. Stisknutí přesunovacího ukazovátka nad ukotvovací ikonou a potom přesunout. Stiskněte jakékoli tlačítko myši, až ikona bude na správném místě.</translation>
     </message>
+    <message>
+        <source>Buddies list</source>
+        <translation>Seznam kamarádů</translation>
+    </message>
 </context>
 <context>
     <name>DesktopDock</name>
