@@ -3,7 +3,8 @@
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
@@ -29,13 +30,13 @@ ExecNotifyPlugin::~ExecNotifyPlugin()
 {
 }
 
-int ExecNotifyPlugin::init(bool firstLoad)
+bool ExecNotifyPlugin::init(bool firstLoad)
 {
 	Q_UNUSED(firstLoad)
 
 	ExecNotifyInstance = new ExecNotify(this);
 
-	return 0;
+	return true;
 }
 
 void ExecNotifyPlugin::done()
@@ -43,3 +44,5 @@ void ExecNotifyPlugin::done()
 }
 
 Q_EXPORT_PLUGIN2(exec_notify, ExecNotifyPlugin)
+
+#include "moc_exec-notify-plugin.cpp"
