@@ -1,10 +1,6 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
 <context>
     <name>@default</name>
-    <message>
-        <source>Status</source>
-        <translation>Stav</translation>
-    </message>
     <message>
         <source>FileDesc</source>
         <translation>Popis souboru</translation>
@@ -17,10 +13,6 @@
         <source>Enter here a file, which will contain descriptions to refresh by module.</source>
         <translation>Zde zadejte soubor, který bude obsahovat popisy k obnově modulem.</translation>
     </message>
-    <message>
-        <source>Force status to be &apos;with description&apos;</source>
-        <translation>Vynutit stav na &apos;s popisem&apos;</translation>
-    </message>
     <message>
         <source>If you choose status without description, module will set it automatically to similar but with description</source>
         <translation>Pokud zvolíte stav bez popisu, modul jej nastaví automaticky na podobný ale s popisem</translation>
@@ -33,5 +25,17 @@
         <source>Allows you to set some custom description manualy, until file contents does not change</source>
         <translation>Umožní vám nastavit některé vlastní popisy ručně, dokud se obsah souboru nezmění</translation>
     </message>
+    <message>
+        <source>Behavior</source>
+        <translation>Chování</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation>Popis</translation>
+    </message>
+    <message>
+        <source>Always add description to status</source>
+        <translation>Vždy přidat popis do stavu</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
