@@ -1,11 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
 <context>
     <name>@default</name>
     <message>
         <source>PC Speaker</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -15,4 +13,4 @@
         <translation>Scriva i toni separato con suoi lungo, per pausa scrivo _ . Per esempio: D2/1 C1#/4 _/2 H0#/3</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
