@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2010 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -29,7 +29,8 @@
 #include "screen-shot-saver.h"
 
 ScreenShotSaver::ScreenShotSaver(QObject *parent) :
-		QObject(parent)
+		QObject{parent},
+		Size{}
 {
 }
 
@@ -81,3 +82,5 @@ QString ScreenShotSaver::saveScreenShot(QPixmap pixmap)
 
 	return path;
 }
+
+#include "moc_screen-shot-saver.cpp"
