@@ -1,6 +1,10 @@
 /*
  * %kadu copyright begin%
- * Copyright 2012 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2013, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -32,5 +36,7 @@ SmsTranslator::~SmsTranslator()
 
 QScriptValue SmsTranslator::tr(const QString &text)
 {
-	return qApp->translate("@default", text.toUtf8().constData());
+	return QCoreApplication::translate("@default", text.toUtf8().constData());
 }
+
+#include "moc_sms-translator.cpp"
