@@ -2,8 +2,8 @@
  * %kadu copyright begin%
  * Copyright 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
  * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
- * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2012, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -27,7 +27,8 @@
 #include "sms-external-sender.h"
 
 SmsExternalSender::SmsExternalSender(const QString &number, QObject *parent) :
-		SmsSender(number, parent)
+		SmsSender{number, parent},
+		Process{}
 {
 }
 
@@ -104,3 +105,5 @@ void SmsExternalSender::cancel()
 
 	deleteLater();
 }
+
+#include "moc_sms-external-sender.cpp"
