@@ -1,219 +1,222 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
 <context>
     <name>@default</name>
     <message>
         <source>SMS</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>General</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SMS Nick</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS</translation>
     </message>
     <message>
         <source>Application</source>
-        <translation type="unfinished"></translation>
+        <translation>Application</translation>
     </message>
     <message>
         <source>Use built-in SMS application</source>
-        <translation type="unfinished"></translation>
+        <translation>Use built-in SMS application</translation>
     </message>
     <message>
         <source>Custom SMS application</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use SMS custom string</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SMS custom string</source>
-        <translation type="unfinished"></translation>
+        <translation>Custom SMS application</translation>
     </message>
     <message>
         <source>Gateways</source>
-        <translation type="unfinished"></translation>
+        <translation>Gateways</translation>
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"></translation>
+        <translation>Shortcuts</translation>
     </message>
     <message>
         <source>Send SMS</source>
-        <translation type="unfinished"></translation>
+        <translation>Send SMS</translation>
     </message>
     <message>
         <source>SMS T-Mobile.pl Gateway</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS T-Mobile.pl Gateway</translation>
     </message>
     <message>
         <source>Sponsored</source>
-        <translation type="unfinished"></translation>
+        <translation>Sponsored</translation>
     </message>
     <message>
         <source>OmnixMultimedia</source>
-        <translation type="unfinished"></translation>
+        <translation>OmnixMultimedia</translation>
     </message>
     <message>
         <source>User ID (48xxxxxxxxx)</source>
-        <translation type="unfinished"></translation>
+        <translation>User ID (48xxxxxxxxx)</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Password</translation>
     </message>
     <message>
         <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
 Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
-        <translation type="unfinished"></translation>
+        <translation>Check this box if your sms application does not understand arguments: number &amp;message&amp;
+Arguments should be separated with spaces. %k argument is converted to number, %m to message</translation>
     </message>
     <message>
         <source>SMS proxy for built-in application</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS proxy for built-in application</translation>
+    </message>
+    <message>
+        <source>Extras</source>
+        <translation>Extras</translation>
+    </message>
+    <message>
+        <source>Your nick for SMS</source>
+        <translation>Your nick for SMS</translation>
+    </message>
+    <message>
+        <source>Use application custom arguments</source>
+        <translation>Use application custom arguments</translation>
+    </message>
+    <message>
+        <source>SMS custom arguments</source>
+        <translation>SMS custom arguments</translation>
+    </message>
+    <message>
+        <source>Behavior</source>
+        <translation>Behavior</translation>
     </message>
 </context>
 <context>
     <name>SmsActions</name>
     <message>
         <source>Send SMS...</source>
-        <translation type="unfinished"></translation>
+        <translation>Send SMS...</translation>
     </message>
 </context>
 <context>
     <name>SmsDialog</name>
     <message>
         <source>Send SMS</source>
-        <translation type="unfinished"></translation>
+        <translation>Send SMS</translation>
     </message>
     <message>
         <source>Recipient</source>
-        <translation type="unfinished"></translation>
+        <translation>Recipient</translation>
     </message>
     <message>
         <source>Select automatically</source>
-        <translation type="unfinished"></translation>
+        <translation>Select automatically</translation>
     </message>
     <message>
         <source>GSM provider</source>
-        <translation type="unfinished"></translation>
+        <translation>GSM provider</translation>
     </message>
     <message>
         <source>Content</source>
-        <translation type="unfinished"></translation>
+        <translation>Content</translation>
     </message>
     <message>
         <source>Signature</source>
-        <translation type="unfinished"></translation>
+        <translation>Signature</translation>
     </message>
     <message>
         <source>Save SMS in history</source>
-        <translation type="unfinished"></translation>
+        <translation>Save SMS in history</translation>
     </message>
     <message>
         <source>&amp;Send</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Send</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Close</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished"></translation>
+        <translation>Clear</translation>
     </message>
     <message>
         <source>Kadu</source>
-        <translation type="unfinished"></translation>
+        <translation>Kadu</translation>
     </message>
     <message>
         <source>SMS application was not specified. Visit the configuration section</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS application was not specified. Visit the configuration section</translation>
     </message>
     <message>
         <source> - Select recipient - </source>
-        <translation type="unfinished"></translation>
+        <translation> - Select recipient - </translation>
     </message>
     <message>
         <source>Sending SMS...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sending SMS...</translation>
     </message>
 </context>
 <context>
     <name>SmsExternalSender</name>
     <message>
         <source>Could not spawn child process. Check if the program is functional</source>
-        <translation type="unfinished"></translation>
+        <translation>Could not spawn child process. Check if the program is functional</translation>
     </message>
     <message>
         <source>The process exited abnormally. The SMS may not be sent</source>
-        <translation type="unfinished"></translation>
+        <translation>The process exited abnormally. The SMS may not be sent</translation>
     </message>
     <message>
         <source>SMS sent</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS sent</translation>
     </message>
 </context>
 <context>
     <name>SmsInternalSender</name>
     <message>
         <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatic gateway selection is not available. Please select SMS gateway manually.</translation>
     </message>
     <message>
         <source>Signature can&apos;t be empty.</source>
-        <translation type="unfinished"></translation>
+        <translation>Signature can&apos;t be empty.</translation>
     </message>
     <message>
         <source>Detecting gateway...</source>
-        <translation type="unfinished"></translation>
+        <translation>Detecting gateway...</translation>
     </message>
     <message>
         <source>Detected gateway: %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Detected gateway: %1.</translation>
     </message>
     <message>
         <source>Sending SMS...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sending SMS...</translation>
     </message>
     <message>
         <source>SMS sent</source>
-        <translation type="unfinished"></translation>
+        <translation>SMS sent</translation>
     </message>
 </context>
 <context>
     <name>SmsTokenReadJob</name>
     <message>
         <source>Invalid paremeters for token read job.</source>
-        <translation type="unfinished"></translation>
+        <translation>Invalid paremeters for token read job.</translation>
     </message>
     <message>
         <source>Downloading token image...</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloading token image...</translation>
     </message>
     <message>
         <source>Unable to fetch token image.</source>
-        <translation type="unfinished"></translation>
+        <translation>Unable to fetch token image.</translation>
     </message>
     <message>
         <source>Unable to read token image.</source>
-        <translation type="unfinished"></translation>
+        <translation>Unable to read token image.</translation>
     </message>
     <message>
         <source>Waiting for entry of token value...</source>
-        <translation type="unfinished"></translation>
+        <translation>Waiting for entry of token value...</translation>
     </message>
     <message>
         <source>No token value provided.</source>
-        <translation type="unfinished"></translation>
+        <translation>No token value provided.</translation>
     </message>
     <message>
         <source>Received token value.</source>
-        <translation type="unfinished"></translation>
+        <translation>Received token value.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
