@@ -1,13 +1,13 @@
 /*
  * %kadu copyright begin%
  * Copyright 2008, 2009, 2010, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
- * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
+ * Copyright 2009, 2010, 2012 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2008, 2009 Tomasz Rostański (rozteck@interia.pl)
  * Copyright 2008, 2009 Michał Podsiadlik (michal@kadu.net)
  * Copyright 2005, 2006 Adrian Smarzewski (adrian@kadu.net)
  * Copyright 2005 Paweł Płuciennik (pawel_p@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2010, 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2010, 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2006, 2007 Dawid Stawiarski (neeo@kadu.net)
  * Copyright 2005, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
@@ -27,9 +27,9 @@
  */
 
 #include "configuration/configuration-file.h"
-#include "core/core.h"
+#include "gui/actions/action-description.h"
 #include "gui/actions/action.h"
-#include "gui/windows/kadu-window.h"
+#include "gui/menu/menu-inventory.h"
 #include "debug.h"
 #include "themes.h"
 
@@ -70,7 +70,10 @@ SoundActions::SoundActions()
 	);
 	connect(MuteActionDescription, SIGNAL(actionCreated(Action *)), this, SLOT(setMuteActionState()));
 
-	Core::instance()->kaduWindow()->insertMenuActionDescription(MuteActionDescription, KaduWindow::MenuKadu, 7);
+	MenuInventory::instance()
+		->menu("main")
+		->addAction(MuteActionDescription, KaduMenu::SectionMiscTools, 7)
+		->update();
 
 	setMuteActionState();
 
@@ -79,7 +82,10 @@ SoundActions::SoundActions()
 
 SoundActions::~SoundActions()
 {
-	Core::instance()->kaduWindow()->removeMenuActionDescription(MuteActionDescription);
+	MenuInventory::instance()
+		->menu("main")
+		->removeAction(MuteActionDescription)
+		->update();
 }
 
 void SoundActions::setMuteActionState()
@@ -103,3 +109,5 @@ void SoundActions::configurationUpdated()
 	SoundManager::instance()->setMute(!config_file.readBoolEntry("Sounds", "PlaySound"));
 	setMuteActionState();
 }
+
+#include "moc_sound-actions.cpp"
