@@ -4,8 +4,8 @@
  * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
  * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
  * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
- * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
+ * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
+ * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
  * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
  * %kadu copyright end%
  *
@@ -38,7 +38,7 @@ SoundPlugin::~SoundPlugin()
 {
 }
 
-int SoundPlugin::init(bool firstLoad)
+bool SoundPlugin::init(bool firstLoad)
 {
 	Q_UNUSED(firstLoad)
 
@@ -49,7 +49,7 @@ int SoundPlugin::init(bool firstLoad)
 	NotificationManager::instance()->registerNotifier(SoundNotifier::instance());
 	SoundActions::registerActions();
 
-	return 0;
+	return true;
 
 }
 
@@ -64,3 +64,5 @@ void SoundPlugin::done()
 }
 
 Q_EXPORT_PLUGIN2(sound, SoundPlugin)
+
+#include "moc_sound-plugin.cpp"
