@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="de">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
 <context>
     <name>@default</name>
     <message>
@@ -15,14 +13,6 @@
         <source>General</source>
         <translation>Allgemein</translation>
     </message>
-    <message>
-        <source>Use sounds</source>
-        <translation>Benutze Klänge</translation>
-    </message>
-    <message>
-        <source>Theme</source>
-        <translation>Thema</translation>
-    </message>
     <message>
         <source>Sound theme</source>
         <translation>Klang-Thema</translation>
@@ -39,6 +29,10 @@
         <source>Play a sound</source>
         <translation>Spiele einen Klang ab</translation>
     </message>
+    <message>
+        <source>Enable sound notifications</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SoundActions</name>
@@ -54,4 +48,4 @@
         <translation>Eigene</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
