@@ -1,50 +1,52 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
 <context>
     <name>@default</name>
     <message>
         <source>Chat</source>
-        <translation type="unfinished"></translation>
+        <translation>Chat</translation>
     </message>
     <message>
         <source>Words fix</source>
-        <translation type="unfinished"></translation>
+        <translation>Words fix</translation>
     </message>
     <message>
         <source>Enable word fix</source>
-        <translation type="unfinished"></translation>
+        <translation>Enable word fix</translation>
+    </message>
+    <message>
+        <source>Spelling</source>
+        <translation>Spelling</translation>
     </message>
 </context>
 <context>
     <name>WordFix</name>
     <message>
         <source>A word to be replaced</source>
-        <translation type="unfinished"></translation>
+        <translation>A word to be replaced</translation>
     </message>
     <message>
         <source>Value to replace with</source>
-        <translation type="unfinished"></translation>
+        <translation>Value to replace with</translation>
     </message>
     <message>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Add</translation>
     </message>
     <message>
         <source>Change</source>
-        <translation type="unfinished"></translation>
+        <translation>Change</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Delete</translation>
     </message>
     <message>
         <source>Word</source>
-        <translation type="unfinished"></translation>
+        <translation>Word</translation>
     </message>
     <message>
         <source>Replace with</source>
-        <translation type="unfinished"></translation>
+        <translation>Replace with</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
